@@ -27,9 +27,15 @@
 #include <config.h>
 #endif
 
+#ifndef HDRL_USE_PRIVATE
+/* Make sure we pull in private functions like hdrl_mime_fringe_amplitudes. */
+#define HDRL_USE_PRIVATE
+#endif
+
 #include "hdrl_fringe.h"
 #include "hdrl_prototyping.h"
 #include "hdrl_random.h"
+
 #include <cpl.h>
 #include <math.h>
 
@@ -42,11 +48,12 @@
 /*-----------------------------------------------------------------------------
                             Functions prototypes
  -----------------------------------------------------------------------------*/
-void test_fringe(void);
 void test_hermite_sum(void);
 void hdrl_fringe_compute_test_input(void);
 void hdrl_fringe_correct_test_input(void);
 void hdrl_fringe_hermite_test(void);
+void hdrl_mime_fringe_amplitudes_test(void);
+void hdrl_mime_fringe_amplitudes_ls_test(void);
 
 static cpl_matrix * hdrl_mime_hermite_functions_create(int n, double center,
           double scale, const cpl_matrix * x);
@@ -253,12 +260,9 @@ static cpl_matrix * hdrl_mime_hermite_functions_create(int n, double center,
     double    rt, xi;
     int       i, j, nr;
 
-/* testing input */
-    if (x == NULL)
-    {
-        cpl_error_set(cpl_func, CPL_ERROR_NULL_INPUT);
-        return NULL;
-    }
+
+    /* testing input */
+    cpl_ensure(x, CPL_ERROR_NULL_INPUT, NULL);
 
     if (n < 1 || scale <= 0.0)
     {
@@ -287,12 +291,12 @@ static cpl_matrix * hdrl_mime_hermite_functions_create(int n, double center,
 /* filling the second column */
     m = cpl_matrix_get_data(funs);
     mx = cpl_matrix_get_data_const(x);
-    if (n >= 2)
-        for (i = 0; i < nr; i++, m += n)
-        {
-            xi = (mx[i] - center) / scale;
-            m[1] = rt * sqrt(2.0) * xi * exp(-0.5 * xi * xi);
-        }
+
+    for (i = 0; i < nr; i++, m += n)
+    {
+		xi = (mx[i] - center) / scale;
+		m[1] = rt * sqrt(2.0) * xi * exp(-0.5 * xi * xi);
+    }
 
 /* filling the remaining columns by recursion */
     m = cpl_matrix_get_data(funs);
@@ -378,19 +382,20 @@ void test_hermite_sum(void)
 
 }
 
+
 void hdrl_fringe_compute_test_input(void)
 {
     cpl_size nx = 21;
     cpl_size ny= 32;
-    hdrl_parameter      *   collapse_params = NULL;
+    hdrl_parameter      *   collapse_params;
     collapse_params = hdrl_collapse_mean_parameter_create();
 
     hdrl_imagelist * ilist_fringe = hdrl_imagelist_new();
     cpl_imagelist *  ilist_obj = cpl_imagelist_new();
     cpl_mask * stat_mask = cpl_mask_new(nx, ny);
 
-    hdrl_image * master = hdrl_image_new(nx, ny);;
-    cpl_image * contrib_map = cpl_image_new(nx, ny, CPL_TYPE_INT);;
+    hdrl_image * master;
+    cpl_image * contrib_map;
 
     hdrl_image * hima1 = hdrl_image_new(nx, ny);
     hdrl_image * hima2 = hdrl_image_new(nx, ny);
@@ -406,44 +411,56 @@ void hdrl_fringe_compute_test_input(void)
     cpl_image_add_scalar(cima2, 10.);
 
 
-
-
-
     hdrl_fringe_compute(NULL, ilist_obj, stat_mask, collapse_params,
-                        &master, &contrib_map);
+                        &master, &contrib_map, NULL);
     cpl_test_error(CPL_ERROR_NULL_INPUT);
+    cpl_test_null(master);
+    cpl_test_null(contrib_map);
+
+    cpl_table *qctable = (cpl_table*)0xbadbeef;
+    hdrl_fringe_compute(NULL, ilist_obj, stat_mask, collapse_params,
+                        &master, &contrib_map, &qctable);
+    cpl_test_error(CPL_ERROR_NULL_INPUT);
+    cpl_test_null(master);
+    cpl_test_null(contrib_map);
+
     hdrl_fringe_compute(ilist_fringe, ilist_obj, stat_mask, NULL,
-                        &master, &contrib_map);
+                        &master, &contrib_map, NULL);
     cpl_test_error(CPL_ERROR_NULL_INPUT);
+    cpl_test_null(master);
+    cpl_test_null(contrib_map);
 
     hdrl_imagelist_set(ilist_fringe, hima1, 0);
     hdrl_imagelist_set(ilist_fringe, hima2, 1);
     cpl_imagelist_set(ilist_obj, cima1, 0);
     hdrl_fringe_compute(ilist_fringe, ilist_obj, stat_mask, collapse_params,
-                         &master, &contrib_map);
+                         &master, &contrib_map, NULL);
     cpl_test_error(CPL_ERROR_INCOMPATIBLE_INPUT);
+    cpl_test_null(master);
+    cpl_test_null(contrib_map);
     cpl_imagelist_set(ilist_obj, cima2, 1);
 
 
-    hdrl_imagelist_unset(ilist_fringe, 1);
-    hdrl_imagelist_unset(ilist_fringe, 0);
+    hima2 = hdrl_imagelist_unset(ilist_fringe, 1);
+    hima1 = hdrl_imagelist_unset(ilist_fringe, 0);
     hdrl_fringe_compute(ilist_fringe, ilist_obj, stat_mask, collapse_params,
-                         &master, &contrib_map);
+                         &master, &contrib_map, NULL);
     cpl_test_error(CPL_ERROR_NULL_INPUT);
+    cpl_test_null(master);
+    cpl_test_null(contrib_map);
 
     /* Images in ilist_fringe and ilist_obj have now different dimensions */
     hdrl_imagelist_set(ilist_fringe, hima_dimen1, 0);
     hdrl_imagelist_set(ilist_fringe, hima_dimen2, 1);
 
     hdrl_fringe_compute(ilist_fringe, ilist_obj, stat_mask, collapse_params,
-                         &master, &contrib_map);
+                         &master, &contrib_map, NULL);
     cpl_test_error(CPL_ERROR_INCOMPATIBLE_INPUT);
+    cpl_test_null(master);
+    cpl_test_null(contrib_map);
 
-    hdrl_imagelist_unset(ilist_fringe, 1);
-    hdrl_imagelist_unset(ilist_fringe, 0);
-
-    hdrl_imagelist_set(ilist_fringe, hima1, 0);
-    hdrl_imagelist_set(ilist_fringe, hima2, 1);
+    hima_dimen2 = hdrl_imagelist_unset(ilist_fringe, 1);
+    hima_dimen1 = hdrl_imagelist_unset(ilist_fringe, 0);
 
     /*
     cpl_msg_warning(cpl_func,"ilist_fringe=%p",ilist_fringe);
@@ -455,23 +472,34 @@ void hdrl_fringe_compute_test_input(void)
     hdrl_fringe_compute(ilist_fringe, ilist_obj, stat_mask, collapse_params,
                            &master, &contrib_map);
     cpl_test_error(CPL_ERROR_NONE);
+    cpl_test_nonnull(master);
+    cpl_test_nonnull(contrib_map);
+    hdrl_image_delete(master);
+    cpl_image_delete(contrib_map);
     */
 
+    /* Test for success when computing a master fringe just from two frames
+       without any object or static masks. */
+    hdrl_imagelist_set(ilist_fringe, hima1, 0);
+    hdrl_imagelist_set(ilist_fringe, hima2, 1);
+    hdrl_fringe_compute(ilist_fringe, NULL, NULL, collapse_params,
+                        &master, &contrib_map, NULL);
+    cpl_test_error(CPL_ERROR_NONE);
+    cpl_test_nonnull(master);
+    cpl_test_nonnull(contrib_map);
+    hdrl_image_delete(master);
+    cpl_image_delete(contrib_map);
+
     /* Final cleanup */
     hdrl_image_delete(hima_dimen1);
     hdrl_image_delete(hima_dimen2);
     hdrl_imagelist_delete(ilist_fringe);
     cpl_imagelist_delete(ilist_obj);
     hdrl_parameter_delete(collapse_params);
-
     cpl_mask_delete(stat_mask);
-    hdrl_image_delete(master);
-    cpl_image_delete(contrib_map);
-
-
-
-
 }
+
+
 void hdrl_fringe_correct_test_input(void)
 {
     cpl_size nx = 21;
@@ -486,6 +514,7 @@ void hdrl_fringe_correct_test_input(void)
 
     hdrl_image * hima1 = hdrl_image_new(nx, ny);
     hdrl_image * hima2 = hdrl_image_new(nx, ny);
+
     hdrl_image * hima_dimen1 = hdrl_image_new(nx+5, ny+10);
     hdrl_image * hima_dimen2 = hdrl_image_new(nx+5, ny+10);
 
@@ -498,42 +527,42 @@ void hdrl_fringe_correct_test_input(void)
     cpl_image_add_scalar(cima2, 10.);
 
 
-    hdrl_fringe_correct(NULL, ilist_obj, stat_mask, masterfringe);
+    hdrl_fringe_correct(NULL, ilist_obj, stat_mask, masterfringe, NULL);
     cpl_test_error(CPL_ERROR_NULL_INPUT);
 
     hdrl_imagelist_set(ilist_fringe, hima1, 0);
     hdrl_imagelist_set(ilist_fringe, hima2, 1);
     cpl_imagelist_set(ilist_obj, cima1, 0);
-    hdrl_fringe_correct(ilist_fringe, ilist_obj, stat_mask, masterfringe);
+    hdrl_fringe_correct(ilist_fringe, ilist_obj, stat_mask, masterfringe, NULL);
     cpl_test_error(CPL_ERROR_INCOMPATIBLE_INPUT);
     cpl_imagelist_set(ilist_obj, cima2, 1);
 
 
-    hdrl_imagelist_unset(ilist_fringe, 1);
-    hdrl_imagelist_unset(ilist_fringe, 0);
-    hdrl_fringe_correct(ilist_fringe, ilist_obj, stat_mask, masterfringe);
+    hima2 = hdrl_imagelist_unset(ilist_fringe, 1);
+    hima1 = hdrl_imagelist_unset(ilist_fringe, 0);
+    hdrl_fringe_correct(ilist_fringe, ilist_obj, stat_mask, masterfringe, NULL);
     cpl_test_error(CPL_ERROR_NULL_INPUT);
 
     /* Images in ilist_fringe and ilist_obj have now different dimensions */
     hdrl_imagelist_set(ilist_fringe, hima_dimen1, 0);
     hdrl_imagelist_set(ilist_fringe, hima_dimen2, 1);
 
-    hdrl_fringe_correct(ilist_fringe, ilist_obj, stat_mask, masterfringe);
+    hdrl_fringe_correct(ilist_fringe, ilist_obj, stat_mask, masterfringe, NULL);
     cpl_test_error(CPL_ERROR_INCOMPATIBLE_INPUT);
 
-    hdrl_imagelist_unset(ilist_fringe, 1);
-    hdrl_imagelist_unset(ilist_fringe, 0);
+    hima_dimen2 = hdrl_imagelist_unset(ilist_fringe, 1);
+    hima_dimen1 = hdrl_imagelist_unset(ilist_fringe, 0);
 
     hdrl_imagelist_set(ilist_fringe, hima1, 0);
     hdrl_imagelist_set(ilist_fringe, hima2, 1);
 
-    hdrl_fringe_correct(ilist_fringe, ilist_obj, stat_mask, masterfringe);
-    cpl_test_error(CPL_ERROR_NULL_INPUT);
+    hdrl_fringe_correct(ilist_fringe, ilist_obj, stat_mask, masterfringe, NULL);
+    cpl_test_error(CPL_ERROR_NONE);
 
-    hdrl_fringe_correct(ilist_fringe, ilist_obj, NULL, masterfringe);
-    cpl_test_error(CPL_ERROR_NULL_INPUT);
+    hdrl_fringe_correct(ilist_fringe, ilist_obj, NULL, masterfringe, NULL);
+    cpl_test_error(CPL_ERROR_NONE);
 
-    hdrl_fringe_correct(ilist_fringe, NULL, NULL, masterfringe);
+    hdrl_fringe_correct(ilist_fringe, NULL, NULL, masterfringe, NULL);
     cpl_test_error(CPL_ERROR_NONE);
 
 
@@ -586,12 +615,12 @@ void hdrl_fringe_correct_test_input(void)
 
 
     cpl_image* contrib_map=NULL;
-    hdrl_parameter      *   collapse_params = NULL;
+    hdrl_parameter      *   collapse_params;
     collapse_params = hdrl_collapse_mean_parameter_create();
     hdrl_image_delete(masterfringe);
     hdrl_fringe_compute(ilist_fringe, ilist_obj, stat_mask, collapse_params,
-                             &masterfringe, &contrib_map);
-    hdrl_fringe_correct(ilist_fringe, NULL, NULL, masterfringe);
+                             &masterfringe, &contrib_map, NULL);
+    hdrl_fringe_correct(ilist_fringe, NULL, NULL, masterfringe, NULL);
     cpl_test_error(CPL_ERROR_NONE);
 
     /* Final cleanup */
@@ -608,9 +637,98 @@ void hdrl_fringe_correct_test_input(void)
 }
 
 
+void hdrl_mime_fringe_amplitudes_test(void)
+{
+    cpl_matrix * matrix;
+    cpl_image * image_double = cpl_image_new(10, 10, CPL_TYPE_DOUBLE);
+    cpl_image * image_float = cpl_image_new(10, 10, CPL_TYPE_FLOAT);
+    cpl_mask * mask = cpl_mask_new(10, 10);
+
+    /* The following test are to check correct error handling for invalid
+       input. */
+    matrix = hdrl_mime_fringe_amplitudes(NULL, NULL);
+    cpl_test_error(CPL_ERROR_NULL_INPUT);
+    cpl_test_null(matrix);
+
+    matrix = hdrl_mime_fringe_amplitudes(image_double, NULL);
+    cpl_test_error(CPL_ERROR_NULL_INPUT);
+    cpl_test_null(matrix);
+
+    matrix = hdrl_mime_fringe_amplitudes(NULL, mask);
+    cpl_test_error(CPL_ERROR_NULL_INPUT);
+    cpl_test_null(matrix);
+
+    /* Check handling of input images that are not doubles. */
+    matrix = hdrl_mime_fringe_amplitudes(image_float, mask);
+    cpl_test_error(CPL_ERROR_INVALID_TYPE);
+    cpl_test_null(matrix);
+
+    /* Check handling of input when nothing is marked in the mask. */
+    cpl_mask_not(mask);
+    cpl_test_error(CPL_ERROR_NONE);
+    matrix = hdrl_mime_fringe_amplitudes(image_double, mask);
+    cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
+    cpl_test_null(matrix);
+
+    cpl_mask_delete(mask);
+    cpl_image_delete(image_float);
+    cpl_image_delete(image_double);
+}
+
+
+void hdrl_mime_fringe_amplitudes_ls_test(void)
+{
+    cpl_matrix * matrix;
+    cpl_image * image_double1 = cpl_image_new(10, 10, CPL_TYPE_DOUBLE);
+    cpl_image * image_double2 = cpl_image_new(10, 10, CPL_TYPE_DOUBLE);
+    cpl_image * image_float = cpl_image_new(10, 10, CPL_TYPE_FLOAT);
+    cpl_mask * mask = cpl_mask_new(10, 10);
+
+    /* The following test are to check correct error handling for invalid
+       input. */
+    matrix = hdrl_mime_fringe_amplitudes_ls(NULL, NULL, NULL);
+    cpl_test_error(CPL_ERROR_NULL_INPUT);
+    cpl_test_null(matrix);
+
+    matrix = hdrl_mime_fringe_amplitudes_ls(NULL, mask, image_double2);
+    cpl_test_error(CPL_ERROR_NULL_INPUT);
+    cpl_test_null(matrix);
+
+    matrix = hdrl_mime_fringe_amplitudes_ls(image_double1, NULL, image_double2);
+    cpl_test_error(CPL_ERROR_NULL_INPUT);
+    cpl_test_null(matrix);
+
+    matrix = hdrl_mime_fringe_amplitudes_ls(image_double1, mask, NULL);
+    cpl_test_error(CPL_ERROR_NULL_INPUT);
+    cpl_test_null(matrix);
+
+    /* Check handling of input images that are not doubles. */
+    matrix = hdrl_mime_fringe_amplitudes_ls(image_float, mask, image_double2);
+    cpl_test_error(CPL_ERROR_INVALID_TYPE);
+    cpl_test_null(matrix);
+
+    matrix = hdrl_mime_fringe_amplitudes_ls(image_double1, mask, image_float);
+    cpl_test_error(CPL_ERROR_INVALID_TYPE);
+    cpl_test_null(matrix);
+
+    /* Check handling of input when nothing is marked in the mask. */
+    cpl_mask_not(mask);
+    cpl_test_error(CPL_ERROR_NONE);
+    matrix = hdrl_mime_fringe_amplitudes_ls(image_double1, mask, image_double2);
+    cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
+    cpl_test_null(matrix);
+
+    cpl_mask_delete(mask);
+    cpl_image_delete(image_float);
+    cpl_image_delete(image_double2);
+    cpl_image_delete(image_double1);
+}
+
+
+
 /*----------------------------------------------------------------------------*/
 /**
- @brief   Unit tests of hdrl_fringe modul;e
+ @brief   Unit tests of hdrl_fringe module.
  **/
 /*----------------------------------------------------------------------------*/
 int main(void)
@@ -622,6 +740,8 @@ int main(void)
     test_hermite_sum();
     hdrl_fringe_compute_test_input(); //problem testing proper inputs
     hdrl_fringe_correct_test_input(); //problem testing proper inputs
+    hdrl_mime_fringe_amplitudes_test();
+    hdrl_mime_fringe_amplitudes_ls_test();
 
     test_hermite_sum();
     return cpl_test_end(0);
