@@ -742,7 +742,7 @@ xsh_respon_slit_nod( cpl_parameterlist* parameters,
                                                          high_abs_win,
                                                          instrument,
                                                          exptime )) == NULL) {
-        xsh_msg_warning("Some error occurred during response computation");
+        xsh_msg_warning("Some error occurred during order by order response computation");
         xsh_print_rec_status(0);
         cpl_error_reset();
      }
@@ -756,7 +756,7 @@ xsh_respon_slit_nod( cpl_parameterlist* parameters,
                                                  instrument,
 						  exptime,
                                                   corr_tell )) == NULL) {
-        xsh_msg_warning("Some error occurred during response computation");
+        xsh_msg_warning("Some error occurred during merged response computation");
         xsh_print_rec_status(0);
         cpl_error_reset();
      } else {
