@@ -486,7 +486,7 @@ static cpl_error_code
   int do_computemap=1;
   int use_model=0;
   int corr_tell=0;
-
+  int scale_nod=0;
   /**************************************************************************/
   /* DFS management */
   /**************************************************************************/
@@ -741,7 +741,7 @@ static cpl_error_code
   check(rect2_frameset_tables=xsh_frameset_ext_table_frames(rect_frameset));
 
   check( comb_frame = xsh_combine_nod(rect2_frameset_tables, combine_nod_param,
-				       file_tag,instrument,&comb_frame_eso));
+				       file_tag,instrument,&comb_frame_eso,scale_nod));
   xsh_free_frameset(&rect2_frameset_tables);
 
   if ( extract_par->method == LOCALIZATION_METHOD ||
@@ -1055,7 +1055,7 @@ static cpl_error_code
     xsh_free_frame( &rect_eff_frame ) ;
     xsh_free_frame( &rect_eff_frame_eso ) ;
     xsh_free_frame( &rect_eff_frame_tab ) ;
-
+    xsh_free_frame( &bpmap );
     xsh_free_frame( &avg_sky ) ;
     xsh_free_frame( &wavemap ) ;
     xsh_free_frame( &slitmap ) ;
