@@ -1090,7 +1090,7 @@ xsh_respon_slit_stare(cpl_parameterlist* parameters,
 
      if ( do_optextract){
 
-        check( xsh_add_product_image( fluxcal_rect_opt1D_frame, frameset,
+        check( xsh_add_product_orders_spectrum( fluxcal_rect_opt1D_frame, frameset,
                                       parameters, RECIPE_ID, instrument,NULL));
 
         check( xsh_add_product_spectrum( fluxcal_merg_opt1D_frame, frameset, 
