@@ -117,6 +117,8 @@ Tag = OBJECT_SLIT_NOD_arm\n\
   - [OPTIONAL] The instrument response table (Tag = RESPONSE_MERGE1D_SLIT_arm)\n\
   - [OPTIONAL] An atmospheric extinction table (Tag = ATMOS_EXT_arm)\n\
   - [OPTIONAL] A telluric mask (Tag = TELL_MASK_arm)\n\
+  - [OPTIONAL] The instrument master response table (Tag = MRESPONSE_MERGE1D_SLIT_arm).\n\
+    If both master and individual response are provided the individual response is preferred.\n\
 Products : \n\
   - PREFIX_ORDER2D_arm (2 dimension)\n\
   - PREFIX_ORDER1D_arm (1 dimension)\n\
@@ -237,7 +239,7 @@ static int xsh_scired_slit_nod_create(cpl_plugin *plugin){
 
   /* Set generic parameters (common to all recipes) */
   check( xsh_parameters_generic( RECIPE_ID, recipe->parameters ) ) ;
-  xsh_parameters_decode_bp(RECIPE_ID,recipe->parameters,-1);
+  xsh_parameters_decode_bp(RECIPE_ID,recipe->parameters,DECODE_BP_FLAG_NOD);
   check( xsh_parameters_pre_overscan( RECIPE_ID, recipe->parameters ) ) ;
   check(xsh_parameters_stack_create(RECIPE_ID,recipe->parameters,stack_param));
 
@@ -302,6 +304,15 @@ static int xsh_scired_slit_nod_create(cpl_plugin *plugin){
     "Sets the number of dummy (empty) ASSONi, ASSOCi and ASSOMi keywords to"
     " create."));
 
+/*
+  check( xsh_parameters_new_int( recipe->parameters, RECIPE_ID,
+     "scale-stack-method",4,
+     "frame stacking scaling method (<=3): 0 (on-scaling); 1 (scaling-uniform on slit); 2 (scaling-slice on slit); 3 (pix-pix scaling)"));
+*/
+  check( xsh_parameters_new_int( recipe->parameters, RECIPE_ID,
+     "scale-combine-nod-method",1,
+     "frame scaling when nod frames are combined: 0 (no-scaling); 1 (scaling)"));
+
  cleanup:
   if ( cpl_error_get_code() != CPL_ERROR_NONE ){
     xsh_error_dump(CPL_MSG_ERROR);
@@ -567,6 +578,9 @@ static void xsh_scired_slit_nod( cpl_parameterlist* parameters,
   xsh_interpolate_bp_param *ipol_bp=NULL;
   int corr_sky=0;
   int cut_uvb_spectrum=0;
+  int scale_nod=0;
+  int scale_stack=4;
+  cpl_frame* frm_rejected=NULL;
   /**************************************************************************/
   /* DFS management */
   /**************************************************************************/
@@ -579,7 +593,7 @@ static void xsh_scired_slit_nod( cpl_parameterlist* parameters,
   assure( instrument->mode == XSH_MODE_SLIT, CPL_ERROR_ILLEGAL_INPUT,
           "Instrument NOT in Slit Mode");
 
-  check(xsh_ensure_raws_number_is_even(raws));
+  check(frm_rejected=xsh_ensure_raws_number_is_even(raws));
   xsh_recipe_params_check(parameters,instrument,RECIPE_ID);
   if(instrument->arm == XSH_ARM_NIR) {
     xsh_instrument_nir_corr_if_JH(raws,instrument);
@@ -623,6 +637,12 @@ static void xsh_scired_slit_nod( cpl_parameterlist* parameters,
   check(ipol_bp = xsh_parameters_interpolate_bp_get(RECIPE_ID,parameters));
  check( corr_sky = xsh_parameters_get_boolean( parameters, RECIPE_ID,
                                                       "correct-sky-by-median"));
+ check( scale_nod = xsh_parameters_get_int( parameters, RECIPE_ID,
+                                               "scale-combine-nod-method"));
+/*
+ check( scale_stack = xsh_parameters_get_int( parameters, RECIPE_ID,
+                                                "scale-stack-method"));
+*/
 
   check( xsh_scired_slit_nod_get_calibs(raws,calib,instrument,
                                        &bpmap,&master_bias,&master_flat,
@@ -714,7 +734,7 @@ static void xsh_scired_slit_nod( cpl_parameterlist* parameters,
   sprintf( comb_tag,"%s_%s",
     rec_prefix, XSH_GET_TAG_FROM_ARM( XSH_ORDER2D, instrument));
   check( comb_frame = xsh_combine_nod( comb_set, combine_nod_par,
-    comb_tag, instrument,&combeso_frame));
+    comb_tag, instrument,&combeso_frame,scale_nod));
 
   /* 2D product */
   check( res2D_frame = xsh_merge_ord( comb_frame, instrument,
@@ -863,7 +883,7 @@ static void xsh_scired_slit_nod( cpl_parameterlist* parameters,
     xsh_free_frameset( &raws_avg);
     xsh_free_frame( &wavemap);
     xsh_free_frame( &slitmap);
-
+    xsh_free_frame(&bpmap);
 
     XSH_FREE( stack_par);
     XSH_FREE( rectify_par);
