@@ -966,7 +966,7 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
   if(cut_uvb_spectrum) {
   if(instrument->arm == XSH_ARM_UVB) {
       xsh_image_cut_dichroic_uvb(rect2_frame_eso);
-      xsh_spectrum_orders_cut_dichroic_uvb(ext_frame_eso,instrument);
+      xsh_spectrum_orders_cut_dichroic_uvb(ext_frame_eso,instrument); 
       xsh_spectrum_cut_dichroic_uvb(res_1D_frame);
       xsh_spectrum_cut_dichroic_uvb(res_2D_frame);
 
@@ -986,8 +986,8 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
           xsh_spectrum_cut_dichroic_uvb(fluxcal_2D_frame);
           xsh_spectrum_cut_dichroic_uvb(fluxcal_1D_frame);
           if ( do_optextract){
-              xsh_spectrum_cut_dichroic_uvb(fluxcal_rect_opt1D_frame);
-              xsh_spectrum_cut_dichroic_uvb(fluxcal_merg_opt1D_frame);
+	    //xsh_spectrum_cut_dichroic_uvb(fluxcal_rect_opt1D_frame);
+	    //xsh_spectrum_cut_dichroic_uvb(fluxcal_merg_opt1D_frame);
           }
 
       }
@@ -1103,7 +1103,7 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
 
      if ( do_optextract){
 
-        check( xsh_add_product_image( fluxcal_rect_opt1D_frame, frameset,
+        check( xsh_add_product_orders_spectrum( fluxcal_rect_opt1D_frame, frameset,
                                       parameters, RECIPE_ID, instrument,
                                       NULL));
 
