@@ -112,8 +112,8 @@ Input Frames:\n\
   - [OPTIONAL] A reference badpixel map (Tag = BP_MAP_RP_arm)\n\
   [OPTIONAL-To compute spectral resolution] Dispersion Table Frame (Tag = DISP_TAB_arm)\n\
 Prepare PRE structures.\n\
-Subtract the master Dark (UVB, VIS and NIR) (xsh_subtract_dark)\n\
-Substract the master Bias (UVB and VIS)(amodigli@pc014007$ vi xsh_wavecal_fail.sofxsh_substract_bias)\n\
+Subtract the master Dark (UVB, VIS and NIR)\n\
+Substract the master Bias (UVB and VIS)\n\
 Divide by Flat.\n\
 Detect and follow arc lines.\n\
 Products:\n\
@@ -137,7 +137,7 @@ Products:\n\
    @return   0 if everything is ok, -1 otherwise
 
    Create the recipe instance and make it available to the application using 
-   the interface. This function is exporamodigli@pc014007$ vi xsh_wavecal_fail.softed.
+   the interface. This function is exported.
 */
 /*---------------------------------------------------------------------------*/
 
