@@ -1460,11 +1460,7 @@ xsh_badpixelmap_flag_saturated_pixels(xsh_pre* pre,xsh_instrument* instr,
     if(xsh_instrument_get_arm(instr) != XSH_ARM_NIR) {
         thresh_max=65000;
     } else {
-    	if (is_flat) {
-    		 thresh_max=100000;
-    	} else {
-    		 thresh_max=42000;
-    	}
+        thresh_max=42000;
         bp_code_sat=QFLAG_SATURATED_DATA;
     }
 
@@ -1482,6 +1478,7 @@ xsh_badpixelmap_flag_saturated_pixels(xsh_pre* pre,xsh_instrument* instr,
     /* position of bottom left edge of NIR frame corresponding to K band */
     int knx=758;
     knx=1000;
+    knx=nx; //removed special treatment of K band: PIPE-7075
     if(flag) {
         double thresh_min=1-cor_val;
         for(j=0;j<ny;j++) {
