@@ -1778,7 +1778,7 @@ xsh_pre* xsh_pre_subsample (xsh_pre* self, const int  binx, const int biny, cons
 
  */
 /*----------------------------------------------------------------------------*/
-void xsh_pre_divide (xsh_pre* self, const xsh_pre * right, double threshold)
+void xsh_pre_divide (xsh_pre* self, const xsh_pre * right, const int is_flat, double threshold)
 {
 
   float *errs1 = NULL;
@@ -1823,8 +1823,26 @@ void xsh_pre_divide (xsh_pre* self, const xsh_pre * right, double threshold)
       }
       */
       qual1[i] |= qual2[i];
+      if ( (is_flat) &&
+    	   (qual2[i] & QFLAG_SATURATED_DATA > 0 ) &&
+		   (qual1[i] & QFLAG_SATURATED_DATA == 0 )
+          ) {
+    	  /* if division was by a saturated flat remove
+    	   * saturated pixel quality
+    	   */
+
+    	  qual1[i] -= QFLAG_SATURATED_DATA;
+
+      }
+      if (qual1[i] > 0 ) {
+    	  /* as QFLAG_SATURATED_DATA was removed the qual1[i] > 0 only
+    	   * if the pixel was bad for other reasons. In this case flag this
+    	   * with QFLAG_CALIB_FILE_DEFECT
+    	   */
+         qual1[i] |= QFLAG_CALIB_FILE_DEFECT;
+      }
     }
-    else if ( fabs(data2[i]) < threshold){
+    if ( fabs(data2[i]) < threshold){
       qual1[i] |= QFLAG_DIVISOR_ZERO;
       errs1[i] = 1;
       data1[i] = 0;
