@@ -1712,4 +1712,18 @@ void xsh_rec_get_nod_kw( cpl_frame * rec_frame, double * throw,
   return ;
 }
 
+cpl_error_code
+xsh_rec_get_nod_extract_slit_min_max(xsh_rec_list* rlist, const double slit_step,
+		double* smin, double* smax)
+{
+
+ double nod_throw = xsh_pfits_get_nodthrow(rlist->header);
+ int nslit = xsh_rec_list_get_nslit(rlist, 0);
+ int hslit = round(0.5 * nod_throw / slit_step);
+ *smax = nslit/2. + hslit;
+ *smin = nslit/2. - hslit;
+
+ return cpl_error_get_code();
+
+}
 /**@}*/
