@@ -161,5 +161,15 @@ double xsh_rec_list_get_lambda_max( xsh_rec_list* list);
 
 cpl_error_code xsh_rec_list_set_slit_min( xsh_rec_list* list,const double val);
 cpl_error_code xsh_rec_list_set_slit_max( xsh_rec_list* list,const double val);
+void xsh_compute_slit_index( float slit_min, float slit_step,
+  xsh_rec_list **from, int *slit_index_tab, int size);
+
+void
+xsh_rec_list_add(xsh_rec_list *dest, xsh_rec_list **from,
+                 int *slit_index, int nb_frames, int no,
+                 int method, const int decode_bp);
+cpl_error_code
+xsh_rec_get_nod_extract_slit_min_max(xsh_rec_list* rlist, const double slit_step,
+		double* smin, double* smax);
 
 #endif  /* XSH_REC_H */
