@@ -861,7 +861,7 @@ cpl_frame* xsh_resid_tab_save( xsh_resid_tab* resid, const char* filename,
     double sig_xgauss, sig_ygauss;
     double fwhm_xgauss, fwhm_ygauss;
     double norm_gauss;
-    int flag;
+    int flag=0;
     lambda = resid->lambda[i];
     order = resid->order[i];
     slit = resid->slit[i];
