@@ -26,7 +26,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-
+#define REGDEBUG_BSPLINE 0
 /*---------------------------------------------------------------------------*/
 /**
  * @defgroup xsh_data_wavemap Wavemap
@@ -160,8 +160,10 @@ xsh_wavemap_list_set_max_size( xsh_wavemap_list * list, int idx,
   pwavemap->order = absorder;
   pwavemap->sky_size = max_size;
   pwavemap->object_size = max_size;
+  pwavemap->all_size = max_size;
   XSH_CALLOC( pwavemap->sky, wavemap_item, max_size);
   XSH_CALLOC( pwavemap->object, wavemap_item, max_size);
+  XSH_CALLOC( pwavemap->all, wavemap_item, max_size);
 
   cleanup:
     return ;
@@ -190,6 +192,7 @@ xsh_wavemap_list_free(xsh_wavemap_list** list)
       xsh_msg_dbg_high( "     Abs Order: %d", pr->order ) ;
       cpl_free( pr->sky);
       cpl_free( pr->object);
+      cpl_free( pr->all);
       if (pr->pol_lambda != NULL){
         xsh_free_polynomial( &(pr->pol_lambda));
       }
@@ -754,6 +757,333 @@ xsh_wavemap_list_save( xsh_wavemap_list * wmap,
   return result ;
 }
 
+
+
+cpl_error_code
+xsh_wavemap_list_sky_image_save( xsh_wavemap_list * smap,
+                             xsh_instrument * instr,
+                             const int abs_ord, const int sid,const int iter)
+{
+
+    xsh_pre* sky_model = NULL ;
+    xsh_pre* fit_model = NULL ;
+    cpl_image* sky_wmap = NULL;
+    cpl_image* sky_smap = NULL;
+
+    float* pdata_sky =NULL;
+    float* perrs_sky =NULL;
+    int* pqual_sky =NULL;
+    float* pdata_fit =NULL;
+    float* perrs_fit =NULL;
+    int* pqual_fit =NULL;
+
+    float* psky_wmap =NULL;
+    float* psky_smap =NULL;
+
+    int order;
+    int sx, sy ;
+    char fname[80];
+    char * final_name = NULL;
+
+    XSH_ASSURE_NOT_NULL( smap ) ;
+    XSH_ASSURE_NOT_NULL( instr ) ;
+
+    sx = instr->config->nx /instr->binx;
+    sy = instr->config->ny /instr->biny;
+    xsh_msg( "Image size:%d,%d", sx, sy ) ;
+
+    /* create a model of the object and the sky as a PRE format frame */
+    sky_model = xsh_pre_new(sx,sy);
+    fit_model = xsh_pre_new(sx,sy);
+
+    pdata_sky = cpl_image_get_data_float(xsh_pre_get_data_const(sky_model));
+    perrs_sky = cpl_image_get_data_float(xsh_pre_get_errs_const(sky_model));
+    pqual_sky = cpl_image_get_data_int(xsh_pre_get_qual_const(sky_model));
+
+    pdata_fit = cpl_image_get_data_float(xsh_pre_get_data_const(fit_model));
+    perrs_fit = cpl_image_get_data_float(xsh_pre_get_errs_const(fit_model));
+    pqual_fit = cpl_image_get_data_int(xsh_pre_get_qual_const(fit_model));
+
+
+    /* associate to object and sky the corresponding wave and slit maps */
+    sky_wmap  = cpl_image_new(sx,sy,XSH_PRE_DATA_TYPE);
+    sky_smap  = cpl_image_new(sx,sy,XSH_PRE_DATA_TYPE);
+
+    psky_wmap = cpl_image_get_data_float(sky_wmap);
+    psky_smap = cpl_image_get_data_float(sky_smap);
+
+    int ix, iy,pix;
+    for( order = 0 ; order < smap->size ; order++ ) {
+
+        wavemap_item * psky = smap->list[order].sky;
+        int sky_size = smap->list[order].sky_size;
+
+        for (int k = 0; k < sky_size; k++) {
+            ix = psky->ix;
+            iy = psky->iy;
+            pix = iy*sx+ix;
+            pdata_sky[pix]=psky->flux;
+            perrs_sky[pix]=psky->sigma;
+            pqual_sky[pix]=psky->qual;
+            pdata_fit[pix]=psky->fitted;
+            perrs_fit[pix]=psky->fit_err;
+            pqual_fit[pix]=psky->qual;
+
+            psky_wmap[pix]=psky->lambda;
+            psky_smap[pix]=psky->slit;
+            psky++;
+        }
+
+    }
+
+#if REGDEBUG_BSPLINE
+    cpl_frame* frm = NULL;
+    sprintf(fname,"sky_model_ord_%2.2d_slice_%2.2d_iter_%2.2d.fits",abs_ord,sid,iter);
+    frm = xsh_pre_save(sky_model,fname, "SKY_MODEL",0);
+    xsh_free_frame(&frm);
+    sprintf(fname,"sky_fit_ord_%2.2d_slice_%2.2d_iter_%2.2d.fits",abs_ord,sid,iter);
+    frm = xsh_pre_save(fit_model,fname, "SKY_FIT",0);
+    xsh_free_frame(&frm);
+    sprintf(fname,"sky_wmap_%2.2d.fits",iter);
+    cpl_image_save(sky_wmap,"sky_wmap.fits", XSH_PRE_DATA_BPP, NULL, CPL_IO_DEFAULT);
+    sprintf(fname,"sky_smap_%2.2d.fits",iter);
+    cpl_image_save(sky_smap,"sky_smap.fits", XSH_PRE_DATA_BPP, NULL, CPL_IO_DEFAULT);
+#endif
+
+    cleanup:
+    cpl_free(final_name);
+    xsh_pre_free(&fit_model);
+    xsh_pre_free(&sky_model);
+    xsh_free_image(&sky_wmap);
+    xsh_free_image(&sky_smap);
+
+    return cpl_error_get_code() ;
+}
+/**
+ * Create a WaveMap Image and save it as an multi extension image
+ *
+ * @param wmap Wavemap list
+ * @param instr instrument arm setting
+ * @param iter id
+ *
+ * @return The created frame
+ */
+cpl_error_code
+xsh_wavemap_list_object_image_save( xsh_wavemap_list * omap,
+                             xsh_instrument * instr,
+                             const int iter)
+{
+
+    xsh_pre* obj_model = NULL ;
+    cpl_image* obj_wmap = NULL;
+    cpl_image* obj_smap = NULL;
+
+    float* pdata_obj =NULL;
+    float* perrs_obj =NULL;
+    int* pqual_obj =NULL;
+
+    float* pobj_wmap =NULL;
+    float* pobj_smap =NULL;
+
+    int order;
+    int sx, sy ;
+    char fname[80];
+
+    XSH_ASSURE_NOT_NULL( omap ) ;
+    XSH_ASSURE_NOT_NULL( instr ) ;
+
+    sx = instr->config->nx / instr->binx;
+    sy = instr->config->ny / instr->biny;
+
+    /* create a model of the object and the sky as a PRE format frame */
+    obj_model = xsh_pre_new(sx,sy);
+
+    pdata_obj = cpl_image_get_data_float(xsh_pre_get_data_const(obj_model));
+    perrs_obj = cpl_image_get_data_float(xsh_pre_get_errs_const(obj_model));
+    pqual_obj = cpl_image_get_data_int(xsh_pre_get_qual_const(obj_model));
+
+    /* associate to object and sky the corresponding wave and slit maps */
+    obj_wmap  = cpl_image_new(sx,sy,XSH_PRE_DATA_TYPE);
+    obj_smap  = cpl_image_new(sx,sy,XSH_PRE_DATA_TYPE);
+
+    pobj_wmap = cpl_image_get_data_float(obj_wmap);
+    pobj_smap = cpl_image_get_data_float(obj_smap);
+
+    int ix, iy,pix;
+    for( order = 0 ; order < omap->size ; order++ ) {
+
+        wavemap_item * pobj = omap->list[order].object;
+        int obj_size = omap->list[order].object_size;
+
+        for (int k = 0; k < obj_size; k++) {
+            ix = pobj->ix;
+            iy = pobj->iy;
+            pix = iy*sx+ix;
+
+            pdata_obj[pix]=pobj->flux;
+            perrs_obj[pix]=pobj->sigma;
+            pqual_obj[pix]=pobj->qual;
+            pobj_wmap[pix]=pobj->lambda;
+            pobj_smap[pix]=pobj->slit;
+
+            pobj++;
+        }
+
+
+    }
+#if REGDEBUG_BSPLINE
+    cpl_frame* frm = NULL;
+    sprintf(fname,"object_model_%2.2d.fits",iter);
+    frm = xsh_pre_save(obj_model,fname, "OBJECT_MODEL",0);
+    xsh_free_frame(&frm);
+
+    sprintf(fname,fname,iter);
+    cpl_image_save(obj_wmap,"object_wmap.fits", XSH_PRE_DATA_BPP, NULL, CPL_IO_DEFAULT);
+    sprintf(fname,"object_smap_%2.2d.fits",iter);
+    cpl_image_save(obj_smap,fname, XSH_PRE_DATA_BPP, NULL, CPL_IO_DEFAULT);
+#endif
+
+    cleanup:
+    xsh_pre_free(&obj_model);
+    xsh_free_image(&obj_wmap);
+    xsh_free_image(&obj_smap);
+
+    return cpl_error_get_code() ;
+}
+
+
+/**
+ * Create a WaveMap Image and save it as an multi extension image
+ *
+ * @param wmap Wavemap list
+ * @param instr instrument arm setting
+ * @param prefix prefix to define Final frame file name
+ *
+ * @return The created frame
+ */
+cpl_error_code
+xsh_wavemap_list_save4debug( xsh_wavemap_list * wmap,
+                             xsh_instrument * instr,
+                             const char * prefix)
+{
+
+    xsh_pre* obj_model = NULL ;
+    xsh_pre* sky_model = NULL ;
+    cpl_image* obj_wmap = NULL;
+    cpl_image* obj_smap = NULL;
+    cpl_image* sky_wmap = NULL;
+    cpl_image* sky_smap = NULL;
+
+    float* pdata_obj =NULL;
+    float* perrs_obj =NULL;
+    int* pqual_obj =NULL;
+
+    float* pdata_sky =NULL;
+    float* perrs_sky =NULL;
+    int* pqual_sky =NULL;
+
+    float* pobj_wmap =NULL;
+    float* pobj_smap =NULL;
+
+    float* psky_wmap =NULL;
+    float* psky_smap =NULL;
+
+    int order;
+    int sx, sy ;
+    char * final_name = NULL;
+
+    XSH_ASSURE_NOT_NULL( wmap ) ;
+    XSH_ASSURE_NOT_NULL( prefix ) ;
+    XSH_ASSURE_NOT_NULL( instr ) ;
+
+    final_name = xsh_stringcat_any( prefix, ".fits", (void*)NULL ) ;
+    xsh_msg( "Entering xsh_wavemap_save, file \"%s\"", final_name ) ;
+
+    sx = instr->config->nx /instr->binx;
+    sy = instr->config->ny /instr->biny;
+    xsh_msg( "Image size:%d,%d", sx, sy ) ;
+
+    /* create a model of the object and the sky as a PRE format frame */
+    obj_model = xsh_pre_new(sx,sy);
+    sky_model = xsh_pre_new(sx,sy);
+
+    pdata_obj = cpl_image_get_data_float(xsh_pre_get_data_const(obj_model));
+    perrs_obj = cpl_image_get_data_float(xsh_pre_get_errs_const(obj_model));
+    pqual_obj = cpl_image_get_data_int(xsh_pre_get_qual_const(obj_model));
+
+    pdata_sky = cpl_image_get_data_float(xsh_pre_get_data_const(sky_model));
+    perrs_sky = cpl_image_get_data_float(xsh_pre_get_errs_const(sky_model));
+    pqual_sky = cpl_image_get_data_int(xsh_pre_get_qual_const(sky_model));
+
+    /* associate to object and sky the corresponding wave and slit maps */
+    obj_wmap  = cpl_image_new(sx,sy,XSH_PRE_DATA_TYPE);
+    obj_smap  = cpl_image_new(sx,sy,XSH_PRE_DATA_TYPE);
+    sky_wmap  = cpl_image_new(sx,sy,XSH_PRE_DATA_TYPE);
+    sky_smap  = cpl_image_new(sx,sy,XSH_PRE_DATA_TYPE);
+
+    pobj_wmap = cpl_image_get_data_float(obj_wmap);
+    pobj_smap = cpl_image_get_data_float(obj_smap);
+
+    psky_wmap = cpl_image_get_data_float(sky_wmap);
+    psky_smap = cpl_image_get_data_float(sky_smap);
+
+    int ix, iy,pix;
+    for( order = 0 ; order < wmap->size ; order++ ) {
+
+        wavemap_item * psky = wmap->list[order].sky;
+        wavemap_item * pobj = wmap->list[order].object;
+        int sky_size = wmap->list[order].sky_size;
+        int obj_size = wmap->list[order].object_size;
+
+        for (int k = 0; k < obj_size; k++) {
+            ix = pobj->ix;
+            iy = pobj->iy;
+            pix = iy*sx+ix;
+            pdata_obj[pix]=pobj->flux;
+            perrs_obj[pix]=pobj->sigma;
+            pqual_obj[pix]=pobj->qual;
+            pobj_wmap[pix]=pobj->lambda;
+            pobj_smap[pix]=pobj->slit;
+            pobj++;
+        }
+
+        for (int k = 0; k < sky_size; k++) {
+            ix = psky->ix;
+            iy = psky->iy;
+            pix = iy*sx+ix;
+            pdata_sky[pix]=psky->flux;
+            perrs_sky[pix]=psky->sigma;
+            pqual_sky[pix]=psky->qual;
+            psky_wmap[pix]=psky->lambda;
+            psky_smap[pix]=psky->slit;
+            psky++;
+        }
+
+    }
+#if REGDEBUG_BSPLINE
+    cpl_frame* frm = NULL;
+    frm = xsh_pre_save(obj_model,"object_model.fits", "OBJECT_MODEL",0);
+    xsh_free_frame(&frm);
+    frm = xsh_pre_save(sky_model,"sky_model.fits", "SKY_MODEL",0);
+    xsh_free_frame(&frm);
+
+    cpl_image_save(obj_wmap,"object_wmap.fits", XSH_PRE_DATA_BPP, NULL, CPL_IO_DEFAULT);
+    cpl_image_save(obj_smap,"object_smap.fits", XSH_PRE_DATA_BPP, NULL, CPL_IO_DEFAULT);
+    cpl_image_save(sky_wmap,"sky_wmap.fits", XSH_PRE_DATA_BPP, NULL, CPL_IO_DEFAULT);
+    cpl_image_save(sky_smap,"sky_smap.fits", XSH_PRE_DATA_BPP, NULL, CPL_IO_DEFAULT);
+#endif
+
+    cleanup:
+    xsh_pre_free(&obj_model);
+    xsh_pre_free(&sky_model);
+    xsh_free_image(&obj_wmap);
+    xsh_free_image(&obj_smap);
+    xsh_free_image(&sky_wmap);
+    xsh_free_image(&sky_smap);
+
+    return cpl_error_get_code() ;
+}
+
 /** 
  * Create a WaveMap Image and save it as a frame.
  * The wave map image is  "raw" image (not a PRE !).
@@ -816,6 +1146,7 @@ xsh_wavemap_list_save2( xsh_wavemap_list * wmap,
   for( order = 0 ; order < wmap->size ; order++ ) {
     int count = 0 ;
 
+    /*
     // Fix 
     if ( wmap->list[order].tcheb_pol_lambda == NULL ) {
       xsh_msg( "Order %d: NULL Polynome", order ) ;
@@ -826,12 +1157,14 @@ xsh_wavemap_list_save2( xsh_wavemap_list * wmap,
 	       order_list->list[order].absorder ) ;
       continue ;
     }
+    */
     /* get start_y, end_y from order list */
     start_y = xsh_order_list_get_starty( order_list, order ) ;
     end_y = xsh_order_list_get_endy( order_list, order ) ;
     xsh_msg_dbg_low( "    Order %d, Ymin: %d, Ymax: %d",
 		     order, start_y, end_y ) ;
-
+    xsh_msg( "    Order %d, Ymin: %d, Ymax: %d",
+                 order, start_y, end_y ) ;
     for ( y = start_y ; y < end_y ; y++ ) {
       double dxmin, dxmax ;
 
@@ -842,6 +1175,8 @@ xsh_wavemap_list_save2( xsh_wavemap_list * wmap,
 					    (double)y, NULL ) ) ;
       xmin = floor(dxmin) ;
       xmax = ceil(dxmax) ;
+      xsh_msg( "    Order %d, Xmin: %d, Xmax: %d",
+                       order, xmin, xmax ) ;
       for (x = xmin ; x<xmax ; x++ ) {
 	count++ ;
 	/*calculate lambda(x,y)*/
@@ -849,7 +1184,9 @@ xsh_wavemap_list_save2( xsh_wavemap_list * wmap,
           (double)y, order);
         if ( cpl_error_get_code() != CPL_ERROR_NONE){
           lambda =0.0;
-          xsh_error_reset();
+          xsh_msg("degx=%d degy=%d", wmap->degx, wmap->degy);
+          xsh_print_rec_status(0);
+          //xsh_error_reset();
         }
 	/*add lambda to image */
 	*(dimg + x + (y*nx)) = (float)lambda ;
