@@ -614,7 +614,7 @@ xsh_combine_nod( cpl_frameset * frames,
 		 xsh_combine_nod_param * param,
 		 const char * fname,
 		 xsh_instrument * instrument,
-		 cpl_frame** res_frame_ext ) ;
+		 cpl_frame** res_frame_ext,const int scale_nod ) ;
 
 
 cpl_frame* 
