@@ -34,14 +34,14 @@
   lambda
 -------------------------------------------------------------------------------*/
 static cpl_size get_index_from_spec(cpl_table* spec_total, double lambda){
-    int* error=NULL;
+    //int* error=NULL;
     cpl_size index;
-    double cdelta1, crval1;
 
-    cdelta1=cpl_table_get(spec_total, "WAVEL",1, error) - 
+    /*
+    double cdelta1=cpl_table_get(spec_total, "WAVEL",1, error) -
                       cpl_table_get(spec_total, "WAVEL",0, error);
-    crval1=cpl_table_get(spec_total, "WAVEL",0, error);
-
+    double crval1=cpl_table_get(spec_total, "WAVEL",0, error);
+    */
     // Obsolete
     //index = (long) (1./cdelta1*lambda-crval1/cdelta1) + 1;
     // Correct formulae for velocity-binned spectra (TO BE USED FOR EFFICIENCY!?)
