@@ -106,13 +106,10 @@ static void xsh_merge_point( double flux_a, double weight_a,
 }
 static void
 xsh_spectrum_clean(xsh_spectrum *spectrum,const int decode_bp){
-    double *spectrum_flux = NULL;
-     double *spectrum_errs = NULL;
-     int *spectrum_qual = NULL;
 
-     spectrum_flux = xsh_spectrum_get_flux( spectrum);
-     spectrum_errs = xsh_spectrum_get_errs( spectrum);
-     spectrum_qual = xsh_spectrum_get_qual( spectrum);
+     //double* spectrum_flux = xsh_spectrum_get_flux( spectrum);
+     //double* spectrum_errs = xsh_spectrum_get_errs( spectrum);
+     //int* spectrum_qual = xsh_spectrum_get_qual( spectrum);
 
      cpl_mask* mask = xsh_qual_to_cpl_mask(spectrum->qual,decode_bp);
 
@@ -182,6 +179,9 @@ static cpl_frame * xsh_merge_ord_with_tag(cpl_frame *rec_frame,
   if (naxis == 2) {
     check( rec_list = xsh_rec_list_load_eso( rec_frame, instrument));
     eso_mode = 1;
+  } else if (naxis == 1) {
+    check( rec_list = xsh_rec_list_load_eso_1d( rec_frame, instrument));
+    eso_mode = 1;
   } else {
     check( rec_list = xsh_rec_list_load( rec_frame, instrument));
   }
@@ -379,7 +379,8 @@ static cpl_frame * xsh_merge_ord_with_tag(cpl_frame *rec_frame,
     cpl_propertylist_erase_regexp(rec_list->header, "^CRPIX2", 0);
     cpl_propertylist_erase_regexp(rec_list->header, "^CDELT1", 0);
     cpl_propertylist_erase_regexp(rec_list->header, "^CDELT2", 0);
-  }check( cpl_propertylist_append( spectrum->flux_header, rec_list->header));
+  }
+  check( cpl_propertylist_append( spectrum->flux_header, rec_list->header));
 
   const char* bunit = xsh_pfits_get_bunit(spectrum->flux_header);
   xsh_pfits_set_bunit(spectrum->errs_header, bunit);
