@@ -217,6 +217,7 @@ double xsh_pfits_get_qc_mbiasrms( const cpl_propertylist * plist);
 int xsh_pfits_get_qc_nhpix( const cpl_propertylist * plist);
 double xsh_pfits_get_qc_mbiasslope( const cpl_propertylist * plist);
 int xsh_pfits_get_qc_ncrh( const cpl_propertylist * plist);
+double xsh_pfits_get_qc_ncrh_mean( const cpl_propertylist * plist);
 double xsh_pfits_get_qc_structx( const cpl_propertylist * plist);
 double xsh_pfits_get_qc_structy( const cpl_propertylist * plist);
 double xsh_pfits_get_qc_ron( const cpl_propertylist * plist);
@@ -248,6 +249,7 @@ void  xsh_pfits_set_qc_ron1_err( cpl_propertylist * plist, double value);
 void  xsh_pfits_set_qc_ron2_err( cpl_propertylist * plist, double value);
 void xsh_pfits_set_qc_ncrh(cpl_propertylist * plist, int value) ;
 void xsh_pfits_set_qc_ncrh_mean(cpl_propertylist * plist, const double value) ;
+void xsh_pfits_set_qc_ncrh_tot(cpl_propertylist * plist, const int value) ;
 void xsh_pfits_set_qc_crrate(cpl_propertylist * plist, double value) ;
 void xsh_pfits_set_qc_mdarkavg(cpl_propertylist * plist, double value);
 void xsh_pfits_set_qc_mdarkmed(cpl_propertylist * plist, double value);
