@@ -279,7 +279,7 @@ xsh_find_cosmics(cpl_frameset* rawFrames,xsh_pre* pre,xsh_clipping_param* crh_cl
   //check( pre->data=xsh_imagelist_collapse_sigclip_iter_create(dataList,3,3,2));
 
 
-  xsh_msg(" Nb of cosmics removed %d", nb_crh_total);
+  xsh_msg("Nb of cosmics removed by frame stacking: %d ", nb_crh_total);
 
   /* Add QC Keywords */
   if (pre->exptime > 0){
