@@ -634,7 +634,7 @@ xsh_utils_efficiency_internal(cpl_table* tbl_obj_spectrum,
     {
       check(pext[i] = xsh_table_interpolate(tbl_atmext, pw[i],col_name_atm_wave, col_name_atm_abs));
       check(pref[i] = xsh_table_interpolate(tbl_ref, pw[i], col_name_ref_wave,col_name_ref_flux));
-      pcor[i] = pow(10,(0.4*pext[i] * (aimprim - airmass)));
+      pcor[i] = pow(10,(-0.4*pext[i] * (aimprim - airmass)));
       eff = 1.e7*1.986e-19/(pw[i]*um2nm);
       if(!isnan(eff)) {
          peph[i]=eff;
